@@ -1,9 +1,11 @@
 # v2
 from ..core  import Imagination
-from ..debug import dump_meta_container
+from ..debug import dump_meta_container, get_logger
 
 from .xml import XMLParser
 
+log = get_logger(__name__)
+
 
 class UnsupportedConfigFileError(RuntimeError):
     """ Error when detect unsupported configuration file """
@@ -15,7 +17,10 @@ class Assembler(object):
             XMLParser(),
         ]
 
-        self._core = Imagination()
+        if core and core.in_standalone_mode():
+            log.info(f'The container in the standalone mode has been provided.')
+
+        self._core = core or Imagination()
 
     @property
     def core(self):
